@@ -60,79 +60,6 @@ iperf_err(struct iperf_test *test, const char *format, ...)
     if (test != NULL && test->json_output && test->json_top != NULL)
 	cJSON_AddStringToObject(test->json_top, "error", str);
     else {
-        if (test != NULL && pthread_mutex_lock(&(test->print_mutex)) != 0) {
-            perror("iperf_err: pthread_mutex_lock");
-        }
-
-	if (test != NULL && test->outfile != NULL && test->outfile != stdout) {
-	    if (ct) {
-		fprintf(test->outfile, "%s", ct);
-	    }
-	    fprintf(test->outfile, "iperf3: %s\n", str);
-	}
-	else {
-	    if (ct) {
-		fprintf(stderr, "%s", ct);
-	    }
-	    fprintf(stderr, "iperf3: %s\n", str);
-	}
-
-        if (test != NULL && pthread_mutex_unlock(&(test->print_mutex)) != 0) {
-            perror("iperf_err: pthread_mutex_unlock");
-        }
-
-    }
-    va_end(argp);
-}
-
-/* Do a printf to stderr or log file as appropriate, then exit(0). */
-void
-iperf_signormalexit(struct iperf_test *test, const char *format, ...)
-{
-    va_list argp;
-
-    va_start(argp, format);
-    iperf_exit(test, 0, format, argp);
-}
-
-/* Do a printf to stderr or log file as appropriate, then exit(1). */
-void
-iperf_errexit(struct iperf_test *test, const char *format, ...)
-{
-    va_list argp;
-
-    va_start(argp, format);
-    iperf_exit(test, 1, format, argp);
-}
-
-/* Do a printf to stderr or log file as appropriate, then exit. */
-void
-iperf_exit(struct iperf_test *test, int exit_code, const char *format, va_list argp)
-{
-    char str[1000];
-    time_t now;
-    struct tm *ltm = NULL;
-    char *ct = NULL;
-
-    /* Timestamp if requested */
-    if (test != NULL && test->timestamps) {
-	time(&now);
-	ltm = localtime(&now);
-	strftime(iperf_timestrerr, sizeof(iperf_timestrerr), iperf_get_test_timestamp_format(test), ltm);
-	ct = iperf_timestrerr;
-    }
-
-    vsnprintf(str, sizeof(str), format, argp);
-    if (test != NULL && test->json_output) {
-        if (test->json_top != NULL) {
-	    cJSON_AddStringToObject(test->json_top, "error", str);
-        }
-	iperf_json_finish(test);
-    } else {
-        if (test != NULL && pthread_mutex_lock(&(test->print_mutex)) != 0) {
-            perror("iperf_errexit: pthread_mutex_lock");
-        }
-
 	if (test && test->outfile && test->outfile != stdout) {
 	    if (ct) {
 		fprintf(test->outfile, "%s", ct);
@@ -145,20 +72,53 @@ iperf_exit(struct iperf_test *test, int exit_code, const char *format, va_list a
 	    }
 	    fprintf(stderr, "iperf3: %s\n", str);
 	}
+    }
+    va_end(argp);
+}
 
-        if (test != NULL && pthread_mutex_unlock(&(test->print_mutex)) != 0) {
-            perror("iperf_errexit: pthread_mutex_unlock");
-        }
+/* Do a printf to stderr or log file as appropriate, then exit. */
+void
+iperf_errexit(struct iperf_test *test, const char *format, ...)
+{
+    va_list argp;
+    char str[1000];
+    time_t now;
+    struct tm *ltm = NULL;
+    char *ct = NULL;
+
+    /* Timestamp if requested */
+    if (test != NULL && test->timestamps) {
+	time(&now);
+	ltm = localtime(&now);
+	strftime(iperf_timestrerr, sizeof(iperf_timestrerr), "%c ", ltm);
+	ct = iperf_timestrerr;
     }
 
+    va_start(argp, format);
+    vsnprintf(str, sizeof(str), format, argp);
+    if (test != NULL && test->json_output && test->json_top != NULL) {
+	cJSON_AddStringToObject(test->json_top, "error", str);
+	iperf_json_finish(test);
+    } else
+	if (test && test->outfile && test->outfile != stdout) {
+	    if (ct) {
+		fprintf(test->outfile, "%s", ct);
+	    }
+	    fprintf(test->outfile, "iperf3: %s\n", str);
+	}
+	else {
+	    if (ct) {
+		fprintf(stderr, "%s", ct);
+	    }
+	    fprintf(stderr, "iperf3: %s\n", str);
+	}
     va_end(argp);
     if (test)
         iperf_delete_pidfile(test);
-    exit(exit_code);
+    exit(1);
 }
 
-int i_errno = 0;
-const char *errarg = NULL;
+int i_errno;
 
 char *
 iperf_strerror(int int_errno)
@@ -187,7 +147,7 @@ iperf_strerror(int int_errno)
             snprintf(errstr, len, "some option you are trying to set is client only");
             break;
         case IEDURATION:
-            snprintf(errstr, len, "test duration valid values are 0 to %d seconds", MAX_TIME);
+            snprintf(errstr, len, "test duration too long (maximum = %d seconds)", MAX_TIME);
             break;
         case IENUMSTREAMS:
             snprintf(errstr, len, "number of parallel streams too large (maximum = %d)", MAX_STREAMS);
@@ -201,7 +161,7 @@ iperf_strerror(int int_errno)
         case IEINTERVAL:
             snprintf(errstr, len, "invalid report interval (min = %g, max = %g seconds)", MIN_INTERVAL, MAX_INTERVAL);
             break;
-        case IEBIND: /* UNUSED */
+    case IEBIND: /* UNUSED */
             snprintf(errstr, len, "--bind must be specified to use --cport");
             break;
         case IEUDPBLOCKSIZE:
@@ -216,9 +176,6 @@ iperf_strerror(int int_errno)
         case IESETSERVERAUTH:
              snprintf(errstr, len, "you must specify a path to a valid RSA private key and a user credential file");
             break;
-        case IESERVERAUTHUSERS:
-             snprintf(errstr, len, "cannot access authorized users file");
-            break;
 	case IEBADFORMAT:
 	    snprintf(errstr, len, "bad format specifier (valid formats are in the set [kmgtKMGT])");
 	    break;
@@ -232,7 +189,7 @@ iperf_strerror(int int_errno)
             snprintf(errstr, len, "this OS does not support sendfile");
             break;
         case IEOMIT:
-            snprintf(errstr, len, "bogus value for --omit (maximum = %d seconds)", MAX_OMIT_TIME);
+            snprintf(errstr, len, "bogus value for --omit");
             break;
         case IEUNIMP:
             snprintf(errstr, len, "an option you are trying to set is not implemented yet");
@@ -271,7 +228,7 @@ iperf_strerror(int int_errno)
             perr = 1;
             break;
         case IECONNECT:
-            snprintf(errstr, len, "unable to connect to server - server may have stopped running or use a different port, firewall issue, etc.");
+            snprintf(errstr, len, "unable to connect to server");
             perr = 1;
 	    herr = 1;
             break;
@@ -300,14 +257,14 @@ iperf_strerror(int int_errno)
             snprintf(errstr, len, "control socket has closed unexpectedly");
             break;
         case IEMESSAGE:
-            snprintf(errstr, len, "received an unknown control message (ensure other side is iperf3 and not iperf)");
+            snprintf(errstr, len, "received an unknown control message");
             break;
         case IESENDMESSAGE:
-            snprintf(errstr, len, "unable to send control message - port may not be available, the other side may have stopped running, etc.");
+            snprintf(errstr, len, "unable to send control message");
             perr = 1;
             break;
         case IERECVMESSAGE:
-            snprintf(errstr, len, "unable to receive control message - port may not be available, the other side may have stopped running, etc.");
+            snprintf(errstr, len, "unable to receive control message");
             perr = 1;
             break;
         case IESENDPARAMS:
@@ -389,15 +346,6 @@ iperf_strerror(int int_errno)
             snprintf(errstr, len, "receive timeout value is incorrect or not in range");
             perr = 1;
             break;
-        case IESNDTIMEOUT:
-            snprintf(errstr, len, "send timeout value is incorrect or not in range");
-            perr = 1;
-            break;
-        case IEUDPFILETRANSFER:
-            snprintf(errstr, len, "cannot transfer file using UDP");
-        case IEUNITVAL:
-            snprintf(errstr, len, "invalid unit value or suffix: '%s'", errarg);
-            break;
         case IERVRSONLYRCVTIMEOUT:
             snprintf(errstr, len, "client receive timeout is valid only in receiving mode");
             perr = 1;
@@ -485,10 +433,7 @@ iperf_strerror(int int_errno)
 	case IETOTALRATE:
 	    snprintf(errstr, len, "total required bandwidth is larger than server limit");
             break;
-        case IETOTALINTERVAL:
-            snprintf(errstr, len, "invalid time interval for calculating average data rate");
-            break;
-        case IESKEWTHRESHOLD:
+    case IESKEWTHRESHOLD:
 	    snprintf(errstr, len, "skew threshold must be a positive number");
             break;
 	case IEIDLETIMEOUT:
@@ -497,66 +442,18 @@ iperf_strerror(int int_errno)
 	case IEBINDDEV:
 	    snprintf(errstr, len, "Unable to bind-to-device (check perror, maybe permissions?)");
             break;
-        case IEBINDDEVNOSUPPORT:
+    case IEBINDDEVNOSUPPORT:
 	    snprintf(errstr, len, "`<ip>%%<dev>` is not supported as system does not support bind to device");
             break;
-        case IEHOSTDEV:
+    case IEHOSTDEV:
 	    snprintf(errstr, len, "host device name (ip%%<dev>) is supported (and required) only for IPv6 link-local address");
             break;        
 	case IENOMSG:
 	    snprintf(errstr, len, "idle timeout for receiving data");
             break;
-        case IESETDONTFRAGMENT:
+    case IESETDONTFRAGMENT:
 	    snprintf(errstr, len, "unable to set IP Do-Not-Fragment flag");
             break;
-        case IESETUSERTIMEOUT:
-            snprintf(errstr, len, "unable to set TCP USER_TIMEOUT");
-            perr = 1;
-            break;
-	case IEPTHREADCREATE:
-            snprintf(errstr, len, "unable to create thread");
-            perr = 1;
-            break;
-	case IEPTHREADCANCEL:
-            snprintf(errstr, len, "unable to cancel thread");
-            perr = 1;
-            break;
-	case IEPTHREADJOIN:
-            snprintf(errstr, len, "unable to join thread");
-            perr = 1;
-            break;
-	case IEPTHREADATTRINIT:
-            snprintf(errstr, len, "unable to create thread attributes");
-            perr = 1;
-            break;
-	case IEPTHREADSIGMASK:
-	    snprintf(errstr, len, "unable to change mask of blocked signals");
-	    break;
-	case IEPTHREADATTRDESTROY:
-            snprintf(errstr, len, "unable to destroy thread attributes");
-        case IECNTLKA:
-            snprintf(errstr, len, "control connection Keepalive period should be larger than the full retry period (interval * count)");
-            perr = 1;
-            break;
-        case IESETCNTLKA:
-            snprintf(errstr, len, "unable to set socket keepalive (SO_KEEPALIVE) option");
-            perr = 1;
-            break;
-        case IESETCNTLKAKEEPIDLE:
-            snprintf(errstr, len, "unable to set socket keepalive TCP period (TCP_KEEPIDLE) option");
-            perr = 1;
-            break;
-        case IESETCNTLKAINTERVAL:
-            snprintf(errstr, len, "unable to set/get socket keepalive TCP retry interval (TCP_KEEPINTVL) option");
-            perr = 1;
-            break;
-        case IESETCNTLKACOUNT:
-            snprintf(errstr, len, "unable to set/get socket keepalive TCP number of retries (TCP_KEEPCNT) option");
-            perr = 1;
-            break;
-        case IEMAXSERVERTESTDURATIONEXCEEDED:
-            snprintf(errstr, len, "client's requested duration exceeds the server's maximum permitted limit");
-            break;
 	default:
 	    snprintf(errstr, len, "int_errno=%d", int_errno);
 	    perr = 1;
