@@ -41,7 +41,6 @@
 #include "iperf.h"
 #include "iperf_api.h"
 #include "iperf_tcp.h"
-#include "iperf_util.h"
 #include "net.h"
 #include "cjson.h"
 
@@ -58,7 +57,7 @@ iperf_tcp_recv(struct iperf_stream *sp)
 {
     int r;
 
-    r = Nread_no_select(sp->socket, sp->buffer, sp->settings->blksize, Ptcp);
+    r = Nread(sp->socket, sp->buffer, sp->settings->blksize, Ptcp);
 
     if (r < 0)
         return r;
@@ -70,7 +69,7 @@ iperf_tcp_recv(struct iperf_stream *sp)
     }
     else {
 	if (sp->test->debug)
-	    printf("Late receive, state = %d-%s\n", sp->test->state, state_to_text(sp->test->state));
+	    printf("Late receive, state = %d\n", sp->test->state);
     }
 
     return r;
@@ -101,7 +100,7 @@ iperf_tcp_send(struct iperf_stream *sp)
     sp->result->bytes_sent += r;
     sp->result->bytes_sent_this_interval += r;
 
-    if (sp->test->debug_level >=  DEBUG_LEVEL_DEBUG)
+    if (sp->test->debug)
 	printf("sent %d bytes of %d, pending %d, total %" PRIu64 "\n",
 	    r, sp->settings->blksize, sp->pending_size, sp->result->bytes_sent);
 
@@ -118,7 +117,7 @@ iperf_tcp_accept(struct iperf_test * test)
 {
     int     s;
     signed char rbuf = ACCESS_DENIED;
-    char    cookie[COOKIE_SIZE] = {0};
+    char    cookie[COOKIE_SIZE];
     socklen_t len;
     struct sockaddr_storage addr;
 
@@ -127,30 +126,13 @@ iperf_tcp_accept(struct iperf_test * test)
         i_errno = IESTREAMCONNECT;
         return -1;
     }
-#if defined(HAVE_SO_MAX_PACING_RATE)
-    /* If fq socket pacing is specified, enable it. */
-
-    if (test->settings->fqrate) {
-	/* Convert bits per second to bytes per second */
-	uint64_t fqrate = test->settings->fqrate / 8;
-	if (fqrate > 0) {
-	    if (test->debug) {
-		printf("Setting fair-queue socket pacing to %"PRIu64"\n", fqrate);
-	    }
-	    if (setsockopt(s, SOL_SOCKET, SO_MAX_PACING_RATE, &fqrate, sizeof(fqrate)) < 0) {
-		warning("Unable to set socket pacing");
-	    }
-	}
-    }
-#endif /* HAVE_SO_MAX_PACING_RATE */
 
     if (Nread(s, cookie, COOKIE_SIZE, Ptcp) < 0) {
         i_errno = IERECVCOOKIE;
-        close(s);
         return -1;
     }
 
-    if (strncmp(test->cookie, cookie, COOKIE_SIZE) != 0) {
+    if (strcmp(test->cookie, cookie) != 0) {
         if (Nwrite(s, (char*) &rbuf, sizeof(rbuf), Ptcp) < 0) {
             iperf_err(test, "failed to send access denied from busy server to new connecting client, errno = %d\n", errno);
         }
@@ -258,6 +240,21 @@ iperf_tcp_listen(struct iperf_test *test)
                 return -1;
             }
         }
+#if defined(HAVE_SO_MAX_PACING_RATE)
+    /* If fq socket pacing is specified, enable it. */
+    if (test->settings->fqrate) {
+	/* Convert bits per second to bytes per second */
+	unsigned int fqrate = test->settings->fqrate / 8;
+	if (fqrate > 0) {
+	    if (test->debug) {
+		printf("Setting fair-queue socket pacing to %u\n", fqrate);
+	    }
+	    if (setsockopt(s, SOL_SOCKET, SO_MAX_PACING_RATE, &fqrate, sizeof(fqrate)) < 0) {
+		warning("Unable to set socket pacing");
+	    }
+	}
+    }
+#endif /* HAVE_SO_MAX_PACING_RATE */
     {
 	unsigned int rate = test->settings->rate / 8;
 	if (rate > 0) {
@@ -312,7 +309,6 @@ iperf_tcp_listen(struct iperf_test *test)
 
         if (listen(s, INT_MAX) < 0) {
             i_errno = IESTREAMLISTEN;
-            close(s);
             return -1;
         }
 
@@ -333,7 +329,6 @@ iperf_tcp_listen(struct iperf_test *test)
     }
     if (test->settings->socket_bufsize && test->settings->socket_bufsize > sndbuf_actual) {
 	i_errno = IESETBUF2;
-    close(s);
 	return -1;
     }
 
@@ -351,7 +346,6 @@ iperf_tcp_listen(struct iperf_test *test)
     }
     if (test->settings->socket_bufsize && test->settings->socket_bufsize > rcvbuf_actual) {
 	i_errno = IESETBUF2;
-    close(s);
 	return -1;
     }
 
@@ -427,18 +421,6 @@ iperf_tcp_connect(struct iperf_test *test)
             return -1;
         }
     }
-#if defined(HAVE_TCP_USER_TIMEOUT)
-    if ((opt = test->settings->snd_timeout)) {
-        if (setsockopt(s, IPPROTO_TCP, TCP_USER_TIMEOUT, &opt, sizeof(opt)) < 0) {
-	    saved_errno = errno;
-	    close(s);
-	    freeaddrinfo(server_res);
-	    errno = saved_errno;
-            i_errno = IESETUSERTIMEOUT;
-            return -1;
-        }
-    }
-#endif /* HAVE_TCP_USER_TIMEOUT */
 
     /* Read back and verify the sender socket buffer size */
     optlen = sizeof(sndbuf_actual);
@@ -477,21 +459,10 @@ iperf_tcp_connect(struct iperf_test *test)
     }
 
     if (test->json_output) {
-    cJSON *sock_bufsize_item = cJSON_GetObjectItem(test->json_start, "sock_bufsize");
-    if (sock_bufsize_item == NULL) {
-    cJSON_AddNumberToObject(test->json_start, "sock_bufsize", test->settings->socket_bufsize);
-    }
-
-    cJSON *sndbuf_actual_item = cJSON_GetObjectItem(test->json_start, "sndbuf_actual");
-    if (sndbuf_actual_item == NULL) {
+	cJSON_AddNumberToObject(test->json_start, "sock_bufsize", test->settings->socket_bufsize);
 	cJSON_AddNumberToObject(test->json_start, "sndbuf_actual", sndbuf_actual);
-    }
-        
-    cJSON *rcvbuf_actual_item = cJSON_GetObjectItem(test->json_start, "rcvbuf_actual");
-    if (rcvbuf_actual_item == NULL) {
 	cJSON_AddNumberToObject(test->json_start, "rcvbuf_actual", rcvbuf_actual);
     }
-    }
 
 #if defined(HAVE_FLOWLABEL)
     if (test->settings->flowlabel) {
@@ -542,10 +513,10 @@ iperf_tcp_connect(struct iperf_test *test)
     /* If socket pacing is specified try to enable it. */
     if (test->settings->fqrate) {
 	/* Convert bits per second to bytes per second */
-	uint64_t fqrate = test->settings->fqrate / 8;
+	unsigned int fqrate = test->settings->fqrate / 8;
 	if (fqrate > 0) {
 	    if (test->debug) {
-		printf("Setting fair-queue socket pacing to %"PRIu64"\n", fqrate);
+		printf("Setting fair-queue socket pacing to %u\n", fqrate);
 	    }
 	    if (setsockopt(s, SOL_SOCKET, SO_MAX_PACING_RATE, &fqrate, sizeof(fqrate)) < 0) {
 		warning("Unable to set socket pacing");
@@ -562,9 +533,6 @@ iperf_tcp_connect(struct iperf_test *test)
 	}
     }
 
-    /* Set common socket options */
-    iperf_common_sockopts(test, s);
-
     if (connect(s, (struct sockaddr *) server_res->ai_addr, server_res->ai_addrlen) < 0 && errno != EINPROGRESS) {
 	saved_errno = errno;
 	close(s);
